#!/usr/bin/env python

# nspire by Conbagui tutorial found here: https://www.deviantart.com/conbagui/art/Candy-corn-tut-639811776

# author: Pocholo
# date: 9/5/20

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY# without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.   


from gimpfu import *
import gettext
import os, sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_halloween_candy_corn_text(customtext, fontname):

    #Initiates the defaults
    pdb.gimp_context_set_defaults()
			
	#Create background layer
    img = pdb.gimp_image_new(1600, 900, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, backLayer, 0)
    pdb.gimp_drawable_fill(backLayer, FILL_WHITE)
    pdb.gimp_context_set_gradient("Candy corn Tri-colors")
    pdb.gimp_drawable_edit_gradient_fill(backLayer, 
                                                  0,  #gradient type - linear
                                                  0,  #offset
                                               TRUE,  #super sample
                                                  3,  #supersample-max depth
                                               0.20,  #supersample-threshole
                                               TRUE,  #dither
                                                800,  #x1
                                                  0,  #y1
                                                800,  #x2
                                                900)  #y2
    pdb.gimp_image_select_rectangle(img, 2, 30, 35, 1540, 830)
    pdb.plug_in_sel2path(img, backLayer) 
    pdb.gimp_selection_none(img)
    pdb.gimp_brushes_set_brush("Candy Corn")
    pdb.gimp_context_set_brush_size(150)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.80)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Random Angle")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors = pdb.gimp_image_get_vectors_by_name(img, _("Selection"))    
    pdb.gimp_drawable_edit_stroke_item(backLayer, vectors)
    non_empty = pdb.gimp_edit_copy(backLayer)
    backcopy = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background copy", 100, LAYER_MODE_HARDLIGHT)
    pdb.gimp_image_add_layer(img, backcopy, 0)
    pdb.gimp_drawable_fill(backcopy, FILL_TRANSPARENT)
    backcopy = pdb.gimp_edit_paste(backcopy, FALSE)
    pdb.gimp_floating_sel_anchor(backcopy) 
    backcopy = pdb.gimp_image_get_layer_by_name(img, "Background copy")
    backcopy = pdb.gimp_image_merge_down(img, backcopy, CLIP_TO_IMAGE)
    backLayer = pdb.gimp_image_get_layer_by_name(img, "Background")
       
    #Create the text		
    size = 475
    textW = size/0.37
    textH = size/1.05
    pdb.gimp_context_set_foreground((0, 0, 0))
    textLayer = pdb.gimp_text_layer_new(img, customtext, fontname, size, PIXELS)
    pdb.gimp_image_add_layer(img, textLayer, 0)
    pdb.gimp_layer_add_alpha(textLayer)
    pdb.gimp_text_layer_set_justification(textLayer, 2)
    pdb.gimp_text_layer_set_letter_spacing(textLayer, 20)
    
    #Resize text
    pdb.gimp_layer_scale (textLayer, textW, textH, TRUE)
    
    #Making the text centered	
    textLayer = pdb.gimp_image_get_active_layer(img)
    pdb.gimp_image_set_active_layer(img, textLayer)
    wh = pdb.gimp_drawable_width(textLayer)
    hh = pdb.gimp_drawable_height(textLayer)
    w = pdb.gimp_image_width(img)
    h = pdb.gimp_image_height(img)
    pdb.gimp_image_set_active_layer(img,textLayer)
    centerx=w/2
    centery=h/2
    adw=wh/2
    adh=hh/2
    sw=centerx - adw
    sh=centery - adh		
    pdb.gimp_layer_set_offsets(textLayer, sw, sh)
    pdb.gimp_layer_resize_to_image_size(textLayer)
    pdb.gimp_layer_set_mode(textLayer, LAYER_MODE_NORMAL)
    pdb.gimp_layer_set_opacity(textLayer, 100)  
    #Rename the text layer
    pdb.gimp_item_set_name(textLayer, "Text")
       
    #Process
    pdb.gimp_display_new(img)
	
	#Drop Shadow
    pdb.python_layerfx_drop_shadow(img, textLayer,
								      ((0, 0, 0)),   #color
											   97,   #opacity
												0,   #contou - linear
												0,   #noise
												3,   #mode - multiply   
											    8,   #spread
											    8,   #size
											  105,   #offset_angle
											   10,   #offset_distance
											 TRUE,   #knockout
											FALSE)   #merge
	
	#Text outer glow
    pdb.python_layerfx_outer_glow(img, textLayer, 
						               (0, 0, 0),   #color
								              45,   #opacity
								               0,   #contou - linear
								               0,   #noise
								               3,   #mode - multiply 
							                   2,   #spread 
								               5,   #size 
							                TRUE,   #knockout 
							               FALSE)   #merge	
	
	#Text inner glow
    pdb.python_layerfx_inner_glow(img, textLayer, 
                                      (82, 1, 1),   #color
                                             100,   #opacity
                                               6,   #contou - hal-round
                                               0,   #noise
                                               4,   #mode - overlay 
                                               1,   #source
                                              14,   #choke 
                                              15,   #size 
                                           FALSE)   #merge
    tinglowLayer = pdb.gimp_image_get_layer_by_name(img, "Text-innerglow")
    pdb.plug_in_gauss(img, tinglowLayer, 70, 70, 1)
	
    #Bevel and emboss
    pdb.python_layerfx_bevel_emboss(img, textLayer, 
												 1,   #style inner bevel
												65,   #depth 
												 0,   #direction 
												20,   #size 
												16,   #soften
											    90,   #angle 
												30,   #altitude 
												 6,   #gloss_contour - gaussian 
										   "White",   #highlight_color 
												 4,   #highlight_mode - screen
											   100,   #highlight_opacity
									 (203, 92, 18),  #shadow_color 
												 5,   #shadow_mode - overlay
											   100,   #shadow_opacity 
												 5,   #surface_contour - half round 
											 FALSE,   #use_texture 
										"3D Green",   #pattern 
											   100,   #scale 
											   100,   #tex_depth 
											  TRUE,   #invert 
											 FALSE)   #merge
    thightLayer = pdb.gimp_image_get_layer_by_name(img, "Text-highlight")
    pdb.plug_in_gauss(img, thightLayer, 30, 30, 1)
    
    #Text gradient overlay
    pdb.python_layerfx_gradient_overlay(img, textLayer, 
						                  "Candy corn",   #gradient 
									                 0,   #gradient_type linear 
									                 0,   #repeat none 
								                 FALSE,   #reverse 
									               100,   #opacity 
									                 0,   #mode - nornal
									               600,   #center_x 
									               425,   #center_y 
									                90,   #angle 
								                   400,   #width 
								                 FALSE)   #merge
    gradLayer = pdb.gimp_image_get_layer_by_name(img, "Text-gradient")
    pdb.gimp_hue_saturation(gradLayer, 0, 5, 10, 30)
    
    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, backLayer)
    #Set the defaults
    pdb.gimp_context_set_defaults()
       
register(
    "pm_create_halloween_candy_corn_text",
    "Creates Halloween candy corn text effect",
    "Creates Halloween candy corn text effect",
    "Pocholo",
    "Pocholo",
    "2021",
    "Candy corn Halloween text",
    "",
    [
    (PF_STRING, "customtext", "Text string", "SWEET!"),
    (PF_FONT, "font", "Font face", "1960s Hippie Thin"),    
    ],
    [],
    pm_create_halloween_candy_corn_text, menu="<Image>/Pocholo-scripts/Candy corn Halloween text",
    domain=("gimp20", gimp.locale_directory))
main()							